@@ -14,16 +14,12 @@
 import traceback
 from rediscluster import StrictRedisCluster
 import sys
+import redis
 
 class RedisCluster(object):
     def __init__(self,redis_nodes):
 
-        # try:
-            self.conn = StrictRedisCluster(startup_nodes=redis_nodes)
-        # except Exception as e:
-        #     log.error("Connect Error:%s"%traceback.format_exc())
-        #     self.conn =  False
-
+        self.conn = StrictRedisCluster(startup_nodes=redis_nodes)
     def redis_set(self,key,value,extime=""):
         '''
         set 类型
@@ -242,7 +238,7 @@ if __name__ == '__main__':
     # log.info(redis_obj.redis_hset("hasss","111111","admin1"))
     # log.info(redis_obj.redis_hdel("hasss","111111"))
     # print(redis_obj.redis_listSet("hasss",["111111","222"],"test3"))
-    print(redis_obj.redis_listGet("hasss"))
+    # print(redis_obj.redis_listGet("hasss"))
     # print(redis_obj.redis_lrem("hasss","test3"))
     # log.info(redis_obj.redis_smembers("hasss"))
     # print(redis_obj.redis_zaddSet("hasssz","0",["test2","test4"]))
